# Angie WASM Modules

## Introduction

[Angie](https://en.angie.software/angie/) is an efficient, powerful, and
scalable web server forked from **nginx** to act as a drop-in replacement. This
allows you to use existing setups without major changes to module layout or
configuration.

This repository contains the source code and documentation for several modules
implementing a technical preview version of WASM support for Angie.

## Core Modules

This collection includes the following core modules, packaged and published in
our [official repositories](https://en.angie.software/angie/docs/installation/):

- **ngx_wasm_module**: Implements basic WASM functionality in Angie.

- **ngx_wasr_module**: Integrates with [WebAssembly Micro
  Runtime](https://github.com/bytecodealliance/wasm-micro-runtime).

- **ngx_wasmtime_module**: Integrates with [Wasmtime](https://wasmtime.dev/).

Documentation for these modules is available on the official website:
https://en.angie.software/angie/docs/configuration/modules/#wasm-modules

For troubleshooting and feedback, refer to:
https://en.angie.software/angie/docs/troubleshooting/


## Angie Module Examples

This repository also provides sample Angie modules that extend the server's WASM
functionality (not to be confused with WASM modules; see [below](#see-also)):

- **ngx_http_host_module**: Provides HTTP functions for WASM, including several
  directives and an API for HTTP-related features.

- **ngx_http_wasm_vars_module**: Creates variables computed by WASM code.

- **ngx_http_wasm_content_module**: Serves as a content handler using WASM code.

- **ngx_http_wasm_filter_module**: Demonstrates embedding WASM for filter
  processing.

- **ngx_http_wasm_event_module**: A placeholder showcasing demo WASM code for
  connections and events. In the example, WASM logic is triggered on requests
  and outputs to the server's stdout.


## See Also

- [Angie WASM SDK](https://git.angie.software/web-server/angie-wasm-sdk/):
  Provides interface definitions and libraries to build WASM modules for Angie
  with higher-level abstractions.

- [WASM Module
  Examples](https://git.angie.software/web-server/angie-wasm-examples/):
  Examples in C and Rust showcasing ways to write Angie-enabled WASM modules
  using the Angie WASM SDK.
